@@ -40,18 +40,32 @@ OC.L10N.register(
     "You restricted the conversation to moderators" : "הגבלת את הדיון למפקחים",
     "{actor} allowed guests" : "אורחים הורשו על ידי {actor}",
     "You allowed guests" : "הרשית אורחים",
+    "An administrator allowed guests" : "ההנהלה איפשרה אורחים",
     "{actor} disallowed guests" : "אורחים נאסרו על ידי {actor}",
     "You disallowed guests" : "אסרת אורחים",
+    "An administrator disallowed guests" : "ההנהלה אסרה על אורחים",
     "{actor} set a password" : "הוגדרה ססמה על ידי {actor}",
     "You set a password" : "הגדרת ססמה",
+    "An administrator set a password" : "ההנהלה הגדירה ססמה",
     "{actor} removed the password" : "הססמה הוסרה על ידי {actor}",
     "You removed the password" : "הסרת את הססמה",
+    "An administrator removed the password" : "הססמה הוסרה על ידי ההנהלה",
     "{actor} added {user}" : "ההוספה של {user} בוצעה על ידי {actor}",
     "You joined the conversation" : "הצטרפת לדיון",
     "{actor} joined the conversation" : "הצטרפות של {actor} לדיון",
     "You added {user}" : "הוספת את {user}",
     "{actor} added you" : "נוספת על ידי {actor}",
+    "An administrator added you" : "נוספת על ידי ההנהלה",
+    "An administrator added {user}" : "ההנהלה הוסיפה את {user}",
     "You left the conversation" : "עזבת את הדיון",
+    "You removed group {group}" : "הסרת את הקבוצה {group}",
+    "An administrator removed group {group}" : "ההנהלה הסירה את הקבוצה {group}",
+    "You shared a file which is no longer available" : "שיתפת קובץ שאינו זמין עוד",
+    "You updated the Matterbridge configuration" : "עדכנת את הגדרות ה־Matterbridge",
+    "You stopped Matterbridge" : "עצרת את Matterbridge",
+    "{actor} deleted a message" : "הודעה נמחקה על ידי {actor}",
+    "You deleted a message" : "מחקת הודעה",
+    "You missed a call from {user}" : "החמצת שיחה עם {user}",
     "Conversation invitation" : "הזמנה לדיון",
     "Click the button below to join." : "יש ללחוץ על הכפתור שלהלן כדי להצטרף.",
     "Meeting ID" : "מזהה פגישה",
@@ -64,11 +78,13 @@ OC.L10N.register(
     "{user} invited you to a group conversation: {call}" : "הוזמנת על ידי {user} לדיון קבוצתי: {call}",
     "Answer call" : "לענות לשיחה",
     "Call back" : "להתקשר בחזרה",
-    "You missed a call from {user}" : "החמצת שיחה עם {user}",
     "A group call has started in {call}" : "החלה שיחה קבוצתית תחת {call}",
     "Open settings" : "פתיחת הגדרות",
     "Conversations" : "דיונים",
     "Messages" : "הודעות",
+    "{user}" : "{user}",
+    "Messages in other conversations" : "הודעות בדיונים אחרים",
+    "The email address is invalid." : "כתובת הדוא״ל שגויה.",
     "Andorra" : "אנדורה",
     "United Arab Emirates" : "איחוד האמירויות הערביות",
     "Afghanistan" : "אפגניסטן",
@@ -352,14 +368,23 @@ OC.L10N.register(
     "Blocked" : "נחסם",
     "Active" : "פעיל",
     "Expired" : "פג",
+    "Matterbridge integration" : "שילוב עם Matterbridge",
+    "Enable Matterbridge integration" : "הפעלת שילוב עם Matterbridge",
+    "Downloading …" : "מתבצעת הורדה…",
+    "Installed version: {version}" : "גרסה מותקנת: {version}",
+    "Failed to execute Matterbridge binary." : "הפעלת הבינרי של Matterbridge נכשלה.",
     "Shared secret" : "סוד משותף",
     "Validate SSL certificate" : "אימות אישור SSL",
+    "Delete this server" : "מחיקת השרת הזה",
     "Saved" : "נשמר",
+    "Add a new server" : "הוספת שרת חדש",
     "STUN server URL" : "כתובת שרת STUN",
     "STUN servers" : "שרתי STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "שרת STUN משמש לאיתור כתובת ה־IP הציבורית של המשתמשים מאחורי נתב.",
     "TURN server URL" : "כתובת שרת TURN",
     "TURN server protocols" : "פרוטוקולים לשרתים מסוג TURN",
+    "Test this server" : "בדיקת השרת הזה",
+    "TURN servers" : "שרתי TURN",
     "Copy link" : "העתקת קישור",
     "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
     "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
@@ -384,6 +409,7 @@ OC.L10N.register(
     "You" : "אני",
     "Show screen" : "הצגת מסך",
     "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
+    "Call in progress" : "מתנהלת שיחה",
     "Favorite" : "סימון כמועדף",
     "Conversation settings" : "הגדרות דיון",
     "Leave conversation" : "יציאה מהדיון",
@@ -395,11 +421,39 @@ OC.L10N.register(
     "Start time (optional)" : "מועד התחלה (רשות)",
     "Save" : "שמירה",
     "Edit" : "עריכה",
+    "Nextcloud URL" : "כתובת Nextcloud",
+    "Nextcloud user" : "משתמש Nextcloud",
+    "User password" : "ססמת משתמש",
+    "Matrix server URL" : "כתובת שרת Matrix",
+    "Matrix channel" : "ערוץ Matrix",
+    "Mattermost server URL" : "כתובת שרת Mattermost",
+    "Mattermost user" : "משתמש Mattermost",
+    "Team name" : "שם צוות",
+    "Channel name" : "שם ערוץ",
+    "Rocket.Chat server URL" : "כתובת שרת Rocket.Chat",
     "Password" : "ססמה",
+    "Rocket.Chat channel" : "ערוץ Rocket.Chat",
+    "Zulip server URL" : "כתובת שרת Zulip",
+    "Bot user name" : "שם המשתמש של הבוט",
+    "Bot API key" : "מפתח ה־API של הבוט",
+    "Zulip channel" : "ערוץ Zulip",
     "API token" : "אסימון API",
+    "Slack channel" : "ערוץ Slack",
+    "Server ID or name" : "מזהה או שם שרת",
+    "Channel ID or name" : "מזהה ערוץ או שם",
+    "Channel" : "ערוץ",
     "Login" : "התחבר",
+    "Chat ID" : "מזהה צ׳אט",
     "Nickname" : "כינוי",
+    "Connection password" : "ססמת התחברות",
+    "IRC channel" : "ערוץ IRC",
     "Client ID" : "מזהה לקו",
+    "Team ID" : "מזהה הקבוצה",
+    "Thread ID" : "מזהה שרשור",
+    "MUC server URL" : "כתובת שרת MUC",
+    "Jabber ID" : "מזהה Jabber",
+    "unknown state" : "מצב לא ידוע",
+    "Bridge saved" : "הגישור נשמר",
     "Remove from favorites" : "הסרה מהמועדפים",
     "Add to favorites" : "הוספה למועדפים",
     "Loading" : "בטעינה",
@@ -422,8 +476,12 @@ OC.L10N.register(
     "Conversation name" : "שם דיון",
     "You are currently waiting in the lobby" : "הנך בהמתנה בלובי",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "בנך בהמתנה בלובי. פגישה זו זומנה ל־{startTime}",
+    "Calls are not supported in your browser" : "אין תמיכה בשיחות בדפדפן שלך",
+    "Access to microphone was denied" : "הגישה למיקרופון נדחתה",
+    "Microphone" : "מיקרופון",
     "Camera" : "מצלמה",
     "Reply" : "תגובה",
+    "Go to file" : "מעבר לקובץ",
     "[Unknown username]" : "[שם משתמש לא ידוע]",
     "Today" : "היום",
     "Yesterday" : "מחר",
@@ -431,6 +489,7 @@ OC.L10N.register(
     "Share files to the conversation" : "שיתוף קבצים לדיון",
     "Upload new files" : "העלאת קבצים חדשים",
     "Share from Files" : "שיתוף מקבצים",
+    "Add emoji" : "הוספת אמוג׳י",
     "Send message" : "שליחת הודעה",
     "File to share" : "קובץ לשיתוף",
     "Invalid path selected" : "הנתיב שנבחר שגוי",
@@ -438,6 +497,7 @@ OC.L10N.register(
     "guest" : "אורח",
     "Demote from moderator" : "הורדה מדרגת פיקוח",
     "Promote to moderator" : "קידום לדרגת פיקוח",
+    "Remove group and members" : "הסרת קבוצה וחברים",
     "Remove participant" : "הסרת משתתף",
     "Add groups" : "הוספת קבוצות",
     "Add emails" : "הוספת כתובות דוא״ל",
@@ -451,13 +511,20 @@ OC.L10N.register(
     "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
     "Chat" : "צ׳אט",
     "Display name: " : "שם תצוגה:",
+    "Choose devices" : "בחירת התקנים",
+    "Attachments folder" : "תיקיית הקבצים המצורפים",
     "Keyboard shortcuts" : "קיצורי מקלדת",
     "Search" : "חיפוש",
+    "Shortcuts while in a call" : "קיצורי דרך בזמן שיחה",
+    "Select location for attachments" : "בחירת מיקום לקבצים מצורפים",
     "Start call" : "התחלת שיחה",
-    "Go to file" : "מעבר לקובץ",
     "Rename conversation" : "שינוי שם הדיון",
+    "Mute others" : "השתקה של אחרים",
+    "Speaker view" : "תצוגת דובר",
     "Grid view" : "תצוגת טבלה",
     "Send" : "שליחה",
+    "Add more files" : "הוספת קבצים נוספים",
+    "No unread mentions" : "אין אזכורים שלא נקראו",
     "Start a conversation" : "התחלת דיון",
     "Message without mention" : "הודעה ללא אזכור",
     "Mention myself" : "אזכור עצמי",
@@ -469,6 +536,7 @@ OC.L10N.register(
     "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
     "Error while sharing file" : "שגיאה בשיתוף הקובץ",
     "Default" : "בררת מחדל",
+    "Speaker {number}" : "רמקול {number}",
     "Access to microphone & camera is only possible with HTTPS" : "גישה למיקרופון ולמצלמה אפשרית רק עם HTTPS",
     "Please move your setup to HTTPS" : "נא להעביר את התצורה שלך ל־HTTPS",
     "Access to microphone & camera was denied" : "הגישה למיקרופון ולמצלמה נדחתה",
@@ -478,6 +546,7 @@ OC.L10N.register(
     "The password is wrong. Try again." : "הססמה שגויה. נא לנסות שוב.",
     "TURN server" : "שרת TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "שרת ה־TURN משמש לתיווך התעבורה מהמשתמשים שנמצאים מאחורי חומת אש.",
+    "Signaling servers" : "שרתי איתות",
     "Android app" : "יישומון ל־Android",
     "iOS app" : "יישומון ל־iOS",
     "New in Talk 6" : "חדש ב־Talk 6",
@@ -492,14 +561,16 @@ OC.L10N.register(
     "Enable video (v)" : "הפעלת וידאו (v)",
     "Conversation, " : "דיון,",
     "Allow guests to join via link " : "לאפשר לאורחים להצטרף דרך קישור",
+    "Remove" : "הסרה",
+    "Bridge with other services" : "גישור עם שירותים אחרים",
+    "More info on Matterbridge." : "מידע נוסף על Matterbridge.",
+    "Enabled" : "מופעל",
+    "User name or e-mail address" : "שם משתמש או כתובת דוא״ל",
+    "Add new bridged channel" : "הוספת ערוץ מגושר חדש",
     "Participant settings" : "הגדרות משתתפים",
     "Add participants to the conversation" : "הוספת משתתפים לדיון",
-    "Projects" : "מיזמים",
     "Share link" : "שיתוף קישור",
     "Exit fullscreen (f)" : "יציאה ממסך מלא (f)",
-    "Fullscreen (f)" : "מסך מלא (f)",
-    "Select a conversation to add to the project" : "בחירת דיון להוספה למיזם",
-    "Remove" : "הסרה",
-    "Enabled" : "מופעל"
+    "Fullscreen (f)" : "מסך מלא (f)"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
