@@ -87,9 +87,18 @@ OC.L10N.register(
     "{actor} removed you" : "{actor} vos a levat",
     "An administrator removed you" : "Un administrator vos a levat",
     "An administrator removed {user}" : "Un administrator a tirat {user}",
+    "{actor} added group {group}" : "{actor} apondèt lo grop {group}",
+    "You added group {group}" : "Avètz apondut lo grop {group}",
+    "An administrator added group {group}" : "Un administrator apondèt lo grop {group}",
     "{actor} removed group {group}" : "{actor} levèt lo grop {group}",
     "You removed group {group}" : "Avètz levat lo grop {group}",
     "An administrator removed group {group}" : "Un administrator tirèt lo grop {group}",
+    "{actor} added circle {circle}" : "{actor} apondèt lo cercle {circle}",
+    "You added circle {circle}" : "Avètz apondut lo cercle {circle}",
+    "An administrator added circle {circle}" : "Un administrator apondèt lo cercle {circle}",
+    "{actor} removed circle {circle}" : "{actor} tirèt lo cercle {circle}",
+    "You removed circle {circle}" : "Avètz tirat lo cercle {circle}",
+    "An administrator removed circle {circle}" : "Un administrator tirèt lo cercle {circle}",
     "{actor} shared a file which is no longer available" : "{actor} partegèt un fichièr qu’es pas pus disponible",
     "You shared a file which is no longer available" : "Partegèretz un fichièr qu'es pas pus disponible",
     "You updated the Matterbridge configuration" : "Avètz actualizada la configuracion Matterbridge",
@@ -101,11 +110,14 @@ OC.L10N.register(
     "You stopped Matterbridge" : "Avètz arrestat Matterbridge",
     "{actor} deleted a message" : "{actor} a suprimit un messatge",
     "You deleted a message" : "Avètz suprimit un messatge",
+    "{actor} cleared the history of the conversation" : "{actor} escafèt l'istoric de la conversacion",
+    "You cleared the history of the conversation" : "Avètz escafat l'istoric de la conversacion",
     "Message deleted by author" : "Messatge suprimit per son autor",
     "Message deleted by {actor}" : "Messatge suprimit per {actor}",
     "Message deleted by you" : "Messatge suprimit per vos",
     "%s (guest)" : "%s (convidat)",
     "You missed a call from {user}" : "Avètz mancat una sonada de {user}",
+    "You tried to call {user}" : "Avètz ensajat de sonar {user}",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Sonada amb %n convidat (Durada {duration})","Sonada amb %n convidats (Durada {duration})"],
     "Call with {user1} and {user2} (Duration {duration})" : "Sonada amb {user1} e {user2} (Durada {duration})",
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Sonada amb {user1}, {user2} e {user3} (Durada {duration})",
@@ -140,6 +152,7 @@ OC.L10N.register(
     "{user} sent you a private message" : "{user} vos a enviat un messatge privat",
     "{user} sent a message in conversation {call}" : "{user} a enviat un messatge dins la conversacion {call}",
     "A deleted user sent a message in conversation {call}" : "Un utilizaire suprimit vos envièt un messatge dins la conversacion {call}",
+    "A guest sent a message in conversation {call}" : "Un convidat a enviat un messatge dins la conversacion {call}",
     "{user} replied to your private message" : "{user} a respondut a vòstre messatge privat",
     "{user} replied to your message in conversation {call}" : "{user} a respondut a vòstre messatge dins la conversacion {call}",
     "A deleted user replied to your message in conversation {call}" : "Un utilizaire suprimit a respondut a vòstre messatge dins la conversacion {call}",
@@ -150,6 +163,7 @@ OC.L10N.register(
     "Answer call" : "Respondre a l’apèl",
     "{user} would like to talk with you" : "{user} volriá vos parlar",
     "Call back" : "Tornar",
+    "A group call has started in {call}" : "Una sonada de grop a començat dins {call}",
     "You missed a group call in {call}" : "Avètz mancat una sonada de grop dins {call}",
     "Someone is requesting the password to access {file}" : "Qualqu’un demanda lo senhal per accedir a {file}",
     "Open settings" : "Dobrir los paramètres",
@@ -566,8 +580,12 @@ OC.L10N.register(
     "Be careful, these actions cannot be undone." : "Fasètz atencion, aquelas accions pòdon pas èsser anulladas.",
     "Leave conversation" : "Quitar la conversacion",
     "Delete conversation" : "Suprimir la conversacion",
+    "Permanently delete this conversation." : "Suprimir permanent aqueste conversacion",
+    "Delete chat messages" : "Suprimir los messatges del chat",
     "Do you really want to delete \"{displayName}\"?" : "Volètz vertadièrament suprimir « {displayName} » ?",
     "Error while deleting conversation" : "Error pendent la supression de la conversacion",
+    "Delete all chat messages" : "Suprimir totes los messatges del chat",
+    "Error while clearing chat history" : "Error pendent l’escafament de l’istoric del chat",
     "Allow guests" : "Autorizar los convidats",
     "Set a password to restrict who can use the public link." : "Definir lo senhal per restrénher qual pòt utilizar lo ligam public.",
     "Password protection" : "Protegir via senhal",
@@ -697,6 +715,7 @@ OC.L10N.register(
     "Copy message link" : "Copiar ligam messatge",
     "Mark as unread" : "Marcar coma pas legit",
     "Go to file" : "Anar al fichièr",
+    "Forward message" : "Transferir lo messatge",
     "Unread messages" : "Messatges pas legits",
     "Sending message" : "Mandadís del messatge",
     "Message sent" : "Messatge mandat",
@@ -713,6 +732,7 @@ OC.L10N.register(
     "Contact" : "Contacte",
     "{stack} in {board}" : "{stack} dins {board}",
     "Remove {fileName}" : "Suprimir {fileName}",
+    "Go to conversation" : "Anar a la conversacion",
     "Open this location in Openstreetmap" : "Dobrir aqueste lòc dins Openstreetmap",
     "[Unknown username]" : "[utilizaire desconegut]",
     "Scroll to bottom" : "Desfilar enbàs",
