@@ -70,10 +70,10 @@ class ChatManager {
 	private $connection;
 	/** @var INotificationManager */
 	private $notificationManager;
-	/** @var ParticipantService */
-	private $participantService;
 	/** @var RoomShareProvider */
 	private $shareProvider;
+	/** @var ParticipantService */
+	private $participantService;
 	/** @var Notifier */
 	private $notifier;
 	/** @var ITimeFactory */
@@ -87,8 +87,8 @@ class ChatManager {
 								IEventDispatcher $dispatcher,
 								IDBConnection $connection,
 								INotificationManager $notificationManager,
-								ParticipantService $participantService,
 								RoomShareProvider $shareProvider,
+								ParticipantService $participantService,
 								Notifier $notifier,
 								ICacheFactory $cacheFactory,
 								ITimeFactory $timeFactory) {
@@ -284,6 +284,25 @@ class ChatManager {
 		);
 	}
 
+	public function clearHistory(Room $chat, string $actorType, string $actorId): IComment {
+		$this->commentsManager->deleteCommentsAtObject('chat', (string) $chat->getId());
+
+		$this->shareProvider->deleteInRoom($chat->getToken());
+
+		$this->notifier->removePendingNotificationsForRoom($chat, true);
+
+		$this->participantService->resetChatDetails($chat);
+
+		return $this->addSystemMessage(
+			$chat,
+			$actorType,
+			$actorId,
+			json_encode(['message' => 'history_cleared', 'parameters' => []]),
+			$this->timeFactory->getDateTime(),
+			false
+		);
+	}
+
 	/**
 	 * @param Room $chat
 	 * @param string $parentId
